Colour scale constructor for lifebrain colors
scale_colour_lifebrain(palette = "main", discrete = TRUE, reverse = FALSE, ...)
| palette | Character name of palette in lifebrain_palettes |
|---|---|
| discrete | Boolean indicating whether color aesthetic is discrete or not |
| reverse | Boolean indicating whether the palette should be reversed |
| ... | Additional arguments passed to discrete_scale() or scale_color_gradientn(), used respectively when discrete is TRUE or FALSE |